@@ -769,7 +769,9 @@ def compute_alpha_signal_rsilo(df=None, core_tokens=['BTC', 'ETH'], rsi_lookback
     data_df[f'S{lo_sig_suffix}{second_token}'] = data_df[f'S{lo_sig_suffix}{second_token}'].ffill()
 
     ### we rebalance monday morning
-    def get_rebalancing_date(row,rebalancing_day=6):
+    def get_filter_date(row,rebalancing_day=6):
+        ##### to get the proper daily close
+        #### we only keep the signal that has been emitted the day before at 23h and pushed there
         if row['weekday'] == rebalancing_day and row['hour'] == 0:
             return True
         else:
@@ -777,9 +779,9 @@ def compute_alpha_signal_rsilo(df=None, core_tokens=['BTC', 'ETH'], rsi_lookback
 
     data_df['weekday'] = data_df.index.weekday
     data_df['hour'] = data_df.index.hour
-    go_reb = lambda x : get_rebalancing_date(x, rebalancing_day=rebalancing_day)
+    go_reb = lambda x : get_filter_date(x, rebalancing_day=rebalancing_day)
     data_df['rebalancing'] = data_df.apply(go_reb, axis=1)
-
+    ##### we rebalance with the close of rebalancing_day :
     def rebalancing_signal_cut(row, token='BTC', lo_sig_suffix='RSILO'):
         if row['rebalancing']:
             return row[f'S{lo_sig_suffix}{token}']
