@@ -591,10 +591,19 @@ def get_accuracy_kpis(strategies, signals_df, under_returns_df):
     return kpis_df
 
 def filter_daily(dataframe):
-    dataframe['hour'] = dataframe.index.hour
-    dataframe = dataframe[dataframe['hour'] == 0]
-    dataframe = dataframe.drop(columns=['hour'])
-    return dataframe
+    dataframe['day'] = dataframe.index.hour == 23
+    daily_aggregated_df = dataframe[dataframe['day']].copy()
+    daily_aggregated_df['date'] = daily_aggregated_df.index
+
+    def truncate_date(row):
+        datet = row['date']
+        return datetime(datet.year, datet.month, datet.day)
+
+    daily_aggregated_df['trunc_date'] = daily_aggregated_df.apply(truncate_date, axis=1)
+    daily_aggregated_df = daily_aggregated_df.set_index('trunc_date')
+    daily_aggregated_df = daily_aggregated_df.drop(columns=['date'])
+    return daily_aggregated_df
+
 
 
 def get_kpi(price_df, default_metrics = [simple_return, annual_return, annual_volatility, sharpe, calmar, mdd]):
